/*
 * lib_do_command.c
 *
 *	Code for VAX LIB$DO_COMMAND routine
 *
 * Description:
 *
 *	Stops program execution and executes the command given as
 *	the parameter. If successful, lib$do_command does not
 *	return control to the ptogram.
 *
 * Bugs:
 *
 *
 * History
 *
 *	07/13/1998 - Kevin Handy
 *		Original version
 *
 *	07/24/1998 - Christof Zeile
 *		Changes to definition of argv and word_integer_length
 *		to remove error messages.
 */

#include <stdio.h>
#include <unistd.h>
#include <stdlib.h>
#include <assert.h>
#include <string.h>
#include "descrip.h"
#include "libdef.h"
#include "lib$routines.h"

/*************************************************************
 * lib$len
 *
 */
unsigned long lib$do_command(const struct dsc$descriptor_s* command)
{
	unsigned short word_integer_length;	/* Length of source string */
	char* data_address;		/* Address of actual data */
	char* work;			/* Working area */
	int status;			/* Status returned from C functions */
	char *argv[1];			/* Command line arguements to pass */

	/*
	 * use STR$ANALYSE_SDESC instead of LIB$ version, because
	 * the LIB$ version calls the STR$ version.
	 */
	lib$analyze_sdesc(command, &word_integer_length,
		&data_address);

	/*
	 * Create a null terminated string for the C run time library
	 */
	work = malloc((size_t)word_integer_length + 1);
	memcpy(work, data_address, (size_t)word_integer_length);
	work[word_integer_length] = '\0';

	/*
	 * Create command line arguements
	 */
	argv[0] = NULL;

	/*
	 * Do the command
	 */
	status = execvp(work, argv);

	/*
	 * If we get here, it obviously didn't work
	 */
	return LIB$_UNECLIERR;
}

