/*
 * lib_movtc.c
 *
 *	Code for VAX LIB$MOVTC routine
 *
 * Description:
 *
 *	The move translated characters routine moves the source string,
 *	character by character, to the destination string after translating
 *	each character using the specified translation table.
 *
 * Bugs:
 *
 * History
 *
 *	02/14/1998 - Kevin Handy
 *		Preliminary design based on LIB$INDEX.
 */

#include <assert.h>
#include <stdlib.h>

#include "descrip.h"
#include "strdef.h"
#include "libdef.h"
#include "lib$routines.h"
#include "str$routines.h"

/* unsigned int str$$resize(struct dsc$descriptor_s* dest, unsigned short size); */

/*************************************************************
 * lib$movtc
 *
 */
unsigned long lib$movtc(
	const struct dsc$descriptor_s* source_string,
	const struct dsc$descriptor_s* fill_string,
	const struct dsc$descriptor_s* tran_string,
	struct dsc$descriptor_s* result_string)
{
	char* source_ptr;		/* Pointer to source string */
	unsigned short source_length;	/* Length of source string */
	char* fill_ptr;			/* Pointer to fill string */
	unsigned short fill_length;	/* Length of fill string */
	char* tran_ptr;			/* Pointer to translation string */
	unsigned short tran_length;	/* Length of translation string */
	char* result_ptr;		/* Destination pointer */
	unsigned short result_length;	/* Destination length */

	int loop;			/* Outer loop */
	unsigned long status;		/* Return status */
	int fillchar;			/* Fill Character */
	char* Buffer;			/* Work Buffer */

	/*
	 * Analyze source strings
	 */
	if (((status = lib$analyze_sdesc(source_string,
		&source_length, &source_ptr)) & 1) == 0)
	{
		return status;
	}
	if (((status = lib$analyze_sdesc(fill_string,
		&fill_length, &fill_ptr)) & 1) == 0)
	{
		return status;
	}
	if (fill_length < 1)
	{
		return STR$_ILLSTRSPE;
	}
	else
	{
		fillchar = *fill_ptr;
	}
	if (((status = lib$analyze_sdesc(tran_string,
		&tran_ptr, &tran_length)) & 1) == 0)
	{
		return status;
	}

	/*
	 * Create a working area
	 */
	if ((Buffer = malloc(source_length + 1U)) == NULL)
	{
		return LIB$_INSVIRMEM;
	}

	/*
	 * We loop from the start position to the end of the
	 * last possible match position in the string.
	 */
	for (loop = 0; loop <= source_length; loop++)
	{
		/*
		 * Inner loop does the actual comparison
		 */
		if (source_ptr[loop] < tran_length)
		{
			Buffer[loop] = tran_ptr[source_ptr[loop]];
		}
		else
		{
			Buffer[loop] = fillchar;
		}
	}

	/*
	 * Lets try to resize the destination
	 */
	if ((status = str$$resize(result_string,
		source_length)) == STR$_NORMAL)
	{
		/*
		 * And then jam in the answer
		 */
		str$analyze_sdesc(result_string, &result_length, &result_ptr);
		status = str$$copy_fill(result_ptr, result_length,
			source_ptr, source_length, fillchar);
	}

	/*
	 * Return the answer
	 */
	free(Buffer);
	return status;
}

