/* <mth$routines.h>
 *
 *	Math run-time library routines.
 */
#ifndef _MTH$ROUTINES_H
#define _MTH$ROUTINES_H
# ifdef __cplusplus
extern "C" {
# endif

/*	MTH$ACOS,MTH$DACOS,MTH$GACOS -- arc cosine of angle in radians */
float mth$acos();
double mth$dacos(), mth$gacos();
/*	MTH$ACOSD,MTH$DACOSD,MTH$GACOSD -- arc cosine of angle in degrees */
float mth$acosd();
double mth$dacosd(), mth$gacosd();
/*	MTH$ASIN,MTH$DASIN,MTH$GASIN -- arc sine in radians */
float mth$asin();
double mth$dasin(), mth$gasin();
/*	MTH$ASIND,MTH$DASIND,MTH$GASIND -- arc sine in degrees */
float mth$asind();
double mth$dasind(), mth$gasind();
/*	MTH$ATAN,MTH$DATAN,MTH$GATAN -- arc tangent in radians */
float mth$atan();
double mth$datan(), mth$gatan();
/*	MTH$ATAN2,MTH$DATAN2,MTH$GATAN2 -- arc tangent in radians with two arguments */
float mth$atan2();
double mth$datan2(), mth$gatan2();
/*	MTH$ATAND,MTH$DATAND,MTH$GATAND -- arc tangent in degrees */
float mth$atand();
double mth$datand(), mth$gatand();
/*	MTH$ATANH,MTH$DATANH,MTH$GATANH -- hyperbolic arc tangent */
float mth$atanh();
double mth$datanh(), mth$gatanh();
/*	MTH$ATAND2,MTH$DATAND2,MTH$GATAND2 -- arc tangent in degrees with two arguments */
float mth$atand2();
double mth$datand2(), mth$gatand2();

/* obtain the index of the first element of a vector having the largest absolute value */
/*	BLAS1$VISAMAX,BLAS1$VIDAMAX,BLAS1$VIGAMAX,BLAS1$VICAMAX,BLAS1$VIZAMAX,BLAS1$VIWAMAX */
long blas1$visamax(), blas1$vidamax(), blas1$vigamax(),
     blas1$vicamax(), blas1$vizamax(), blas1$viwamax();

/* obtain the sum of the absolute values of the elements of a vector */
/*	BLAS1$VSASUM,BLAS1$VDASUM,BLAS1$VGASUM,BLAS1$VSCASUM,BLAS1$VDZASUM,BLAS1$VGWASUM */
float blas1$vsasum();
double blas1$vdasum(), blas1$vgasum();
/*- mumble blas1$vscasum(), blas1$vdzasum(), blas1$vgwasum(); */

/* multiply a vector by a scalar and add a vector */
/*	BLAS1$VSAXPY,BLAS1$VDAXPY,BLAS1$VGAXPY,BLAS1$VCAXPY,BLAS1$VZAXPY,BLAS1$VWAXPY */
int blas1$vsaxpy(), blas1$vdaxpy(), blas1$vgaxpy(),
    blas1$vcaxpy(), blas1$vzaxpy(), blas1$vwaxpy();

/* copy a vector */
/*	BLAS1$VSCOPY,BLAS1$VDCOPY,BLAS1$VCCOPY,BLAS1$VZCOPY */
int blas1$vscopy(), blas1$vdcopy(), blas1$vccopy(), blas1$vzcopy();

/* obtain the inner product of two vectors */
/*	BLAS1$VSDOT,BLAS1$VDDOT,BLAS1$VGDOT,BLAS1$VCDOTU,BLAS1$VCDOTC */
/*	BLAS1$VZDOTU	-- Obtain the Inner Product of Two Vectors */
/*	BLAS1$VZDOTC	-- Obtain the Inner Product of Two Vectors */
/*	BLAS1$VWDOTU	-- Obtain the Inner Product of Two Vectors */
/*	BLAS1$VWDOTC	-- Obtain the Inner Product of Two Vectors */
float blas1$vsdot();
double blas1$vddot(), blas1$vgdot();
/*- mumble blas1$vcdotu(), blas1$vcdotc(), blas1$vzdotu(), blas1$vzdotc(); */
/*- mumble blas1$vwdotu(), blas1$vwdotc(); */

/* obtain the euclidean norm of a vector */
/*	BLAS1$VSNRM2,BLAS1$VDNRM2,BLAS1$VGNRM2,BLAS1$VSCNRM2,BLAS1$VDZNRM2,BLAS1$VGWNRM2 */
float blas1$vsnrm2();
double blas1$vdnrm2(), blas1$vgnrm2();
/*- mumble blas1$vscnrm2(), blas1$vdznrm2(), blas1$vgwnrm2(); */

/* apply a givens plane rotation */
/*	BLAS1$VSROT,BLAS1$VDROT,BLAS1$VGROT,BLAS1$VCSROT,BLAS1$VZDROT,BLAS1$VWGROT */
int blas1$vsrot(), blas1$vdrot(), blas1$vgrot(),
    blas1$vcsrot(), blas1$vzdrot(), blas1$vwgrot();

/* generate the elements for a givens plane rotation */
/*	BLAS1$VSROTG,BLAS1$VDROTG,BLAS1$VGROTG,BLAS1$VCROTG,BLAS1$VZROTG,BLAS1$VWROTG */
int blas1$vsrotg(), blas1$vdrotg(), blas1$vgrotg(),
    blas1$vcrotg(), blas1$vzrotg(), blas1$vwrotg();

/* scale the elements of a vector */
/*	BLAS1$VSSCAL,BLAS1$VDSCAL,BLAS1$VGSCAL,BLAS1$VCSCAL,BLAS1$VCSSCAL */
/*	BLAS1$VZSCAL,BLAS1$VWSCAL,BLAS1$VZDSCAL,BLAS1$VWGSCAL */
int blas1$vsscal(), blas1$vdscal(), blas1$vgscal(),
    blas1$vcscal(), blas1$vcsscal(), blas1$vzscal(),
    blas1$vwscal(), blas1$vzdscal(), blas1$vwgscal();

/* swap the elements of two vectors */
/*	BLAS1$VSSWAP,BLAS1$VDSWAP,BLAS1$VCSWAP,BLAS1$VZSWAP */
int blas1$vsswap(), blas1$vdswap(), blas1$vcswap(), blas1$vzswap();

/*	MTH$CABS,MTH$CDABS,MTH$CGABS -- complex absolute value */
float mth$cabs();
double mth$cdabs(), mth$cgabs();

/*	MTH$CCOS	-- cosine of a complex number (F-floating value) */
/*- complex float mth$ccos(); */
/*	MTH$CEXP	-- complex exponential (F-floating value) */
/*- complex float mth$cexp(); */
/*	MTH$CLOG	-- complex natural logarithm (F-floating value) */
/*- complex float mth$clog(); */
/*	MTH$CMPLX,MTH$DCMPLX,MTH$GCMPLX -- complex number made floating point */
/*- complex float mth$cmplx(); */
/*- double complex mth$dcmplx(), mth$gcmplx(); */
/*	MTH$CONJG,MTH$DCONJG,MTH$GCONJG -- conjugate of a complex number */
/*- complex float mth$conjg(); */
/*- double complex mth$dconjg(), mth$gconjg(); */

/*	MTH$COS,MTH$DCOS,MTH$GCOS -- cosine of angle in radians */
float mth$cos();
double mth$dcos(), mth$gcos();
/*	MTH$COSD,MTH$DCOSD,MTH$GCOSD -- cosine of angle in degrees */
float mth$cosd();
double mth$dcosd(), mth$gcosd();
/*	MTH$COSH,MTH$DCOSH,MTH$GCOSH -- hyperbolic cosine */
float mth$cosh();
double mth$dcosh(), mth$gcosh();
/*	MTH$CSIN	-- sine of a complex number (F-floating value) */
/*- complex float mth$csin(); */
/*	MTH$CSQRT	-- complex square root (F-floating value) */
/*- complex float mth$csqrt(); */

/*	MTH$CVT_D_G,MTH$CVT_G_D -- convert one double-precision value */
double mth$cvt_d_g(), mth$cvt_g_d();
/*	MTH$CVT_DA_GA,MTH$CVT_GA_DA -- convert an array of double-precision values */
double *mth$cvt_da_ga(), *mth$cvt_ga_da();

/*	MTH$CDCOS,MTH$CGCOS -- cosine of a complex number */
/*- double complex mth$cdcos(), mth$cgcos(); */
/*	MTH$CDEXP,MTH$CGEXP -- complex exponential */
/*- double complex mth$cdexp(), mth$cgexp(); */
/*	MTH$CDLOG,MTH$CGLOG -- complex natural logarithm */
/*- double complex mth$cdlog(), mth$cglog(); */
/*	MTH$CDSIN,MTH$CGSIN -- sine of complex number */
/*- double complex mth$cdsin(), mth$cgsin(); */
/*	MTH$CDSQRT,MTH$CGSQRT -- complex square root */
/*- double complex mth$cdsqrt(), mth$cgsqrt(); */

/*	MTH$EXP		-- exponential */
float mth$exp();
/*	MTH$DEXP	-- exponential */
double mth$dexp();
/*	MTH$GEXP	-- exponential */
double mth$gexp();
/*	MTH$VJFOLRLP_MA_V5 -- first order linear recurrence --- multiplication and addition --- last value */
long mth$vjfolrlp_ma_v5();
/*	MTH$VFFOLRLP_MA_V5 -- First Order Linear Recurrence --- Multiplication and Addition --- Last Value */
float mth$vffolrlp_ma_v5();
/*	MTH$VDFOLRLP_MA_V5 -- First Order Linear Recurrence --- Multiplication and Addition --- Last Value */
double mth$vdfolrlp_ma_v5();
/*	MTH$VGFOLRLP_MA_V5 -- First Order Linear Recurrence --- Multiplication and Addition --- Last Value */
double mth$vgfolrlp_ma_v5();
/*	MTH$VJFOLRLN_MA_V5 -- First Order Linear Recurrence --- Multiplication and Addition --- Last Value */
long mth$vjfolrln_ma_v5();
/*	MTH$VFFOLRLN_MA_V5 -- First Order Linear Recurrence --- Multiplication and Addition --- Last Value */
float mth$vffolrln_ma_v5();
/*	MTH$VDFOLRLN_MA_V5 -- First Order Linear Recurrence --- Multiplication and Addition --- Last Value */
double mth$vdfolrln_ma_v5();
/*	MTH$VGFOLRLN_MA_V5 -- First Order Linear Recurrence --- Multiplication and Addition --- Last Value */
double mth$vgfolrln_ma_v5();
/*	MTH$VJFOLRLP_M_V2 -- First Order Linear Recurrence --- Multiplication or Addition --- Last Value */
long mth$vjfolrlp_m_v2();
/*	MTH$VFFOLRLP_M_V2 -- First Order Linear Recurrence --- Multiplication or Addition --- Last Value */
float mth$vffolrlp_m_v2();
/*	MTH$VDFOLRLP_M_V2 -- First Order Linear Recurrence --- Multiplication or Addition --- Last Value */
double mth$vdfolrlp_m_v2();
/*	MTH$VGFOLRLP_M_V2 -- First Order Linear Recurrence --- Multiplication or Addition --- Last Value */
double mth$vgfolrlp_m_v2();
/*	MTH$VJFOLRLN_M_V2 -- First Order Linear Recurrence --- Multiplication or Addition --- Last Value */
long mth$vjfolrln_m_v2();
/*	MTH$VFFOLRLN_M_V2 -- First Order Linear Recurrence --- Multiplication or Addition --- Last Value */
float mth$vffolrln_m_v2();
/*	MTH$VDFOLRLN_M_V2 -- First Order Linear Recurrence --- Multiplication or Addition --- Last Value */
double mth$vdfolrln_m_v2();
/*	MTH$VGFOLRLN_M_V2 -- First Order Linear Recurrence --- Multiplication or Addition --- Last Value */
double mth$vgfolrln_m_v2();
/*	MTH$VJFOLRLP_A_V2 -- First Order Linear Recurrence --- Multiplication or Addition --- Last Value */
long mth$vjfolrlp_a_v2();
/*	MTH$VFFOLRLP_A_V2 -- First Order Linear Recurrence --- Multiplication or Addition --- Last Value */
float mth$vffolrlp_a_v2();
/*	MTH$VDFOLRLP_A_V2 -- First Order Linear Recurrence --- Multiplication or Addition --- Last Value */
double mth$vdfolrlp_a_v2();
/*	MTH$VGFOLRLP_A_V2 -- First Order Linear Recurrence --- Multiplication or Addition --- Last Value */
double mth$vgfolrlp_a_v2();
/*	MTH$VJFOLRLN_A_V2 -- First Order Linear Recurrence --- Multiplication or Addition --- Last Value */
long mth$vjfolrln_a_v2();
/*	MTH$VFFOLRLN_A_V2 -- First Order Linear Recurrence --- Multiplication or Addition --- Last Value */
float mth$vffolrln_a_v2();
/*	MTH$VDFOLRLN_A_V2 -- First Order Linear Recurrence --- Multiplication or Addition --- Last Value */
double mth$vdfolrln_a_v2();
/*	MTH$VGFOLRLN_A_V2 -- First Order Linear Recurrence --- Multiplication or Addition --- Last Value */
double mth$vgfolrln_a_v2();
/*	MTH$VJFOLRP_MA_V15 -- First Order Linear Recurrence --- Multiplication and Addition */
int mth$vjfolrp_ma_v15();
/*	MTH$VFFOLRP_MA_V15 -- First Order Linear Recurrence --- Multiplication and Addition */
int mth$vffolrp_ma_v15();
/*	MTH$VDFOLRP_MA_V15 -- First Order Linear Recurrence --- Multiplication and Addition */
int mth$vdfolrp_ma_v15();
/*	MTH$VGFOLRP_MA_V15 -- First Order Linear Recurrence --- Multiplication and Addition */
int mth$vgfolrp_ma_v15();
/*	MTH$VJFOLRN_MA_V15 -- First Order Linear Recurrence --- Multiplication and Addition */
int mth$vjfolrn_ma_v15();
/*	MTH$VFFOLRN_MA_V15 -- First Order Linear Recurrence --- Multiplication and Addition */
int mth$vffolrn_ma_v15();
/*	MTH$VDFOLRN_MA_V15 -- First Order Linear Recurrence --- Multiplication and Addition */
int mth$vdfolrn_ma_v15();
/*	MTH$VGFOLRN_MA_V15 -- First Order Linear Recurrence --- Multiplication and Addition */
int mth$vgfolrn_ma_v15();
/*	MTH$VJFOLRP_M_V8 -- First Order Linear Recurrence --- Multiplication or Addition */
int mth$vjfolrp_m_v8();
/*	MTH$VFFOLRP_M_V8 -- First Order Linear Recurrence --- Multiplication or Addition */
int mth$vffolrp_m_v8();
/*	MTH$VDFOLRP_M_V8 -- First Order Linear Recurrence --- Multiplication or Addition */
int mth$vdfolrp_m_v8();
/*	MTH$VGFOLRP_M_V8 -- First Order Linear Recurrence --- Multiplication or Addition */
int mth$vgfolrp_m_v8();
/*	MTH$VJFOLRN_M_V8 -- First Order Linear Recurrence --- Multiplication or Addition */
int mth$vjfolrn_m_v8();
/*	MTH$VFFOLRN_M_V8 -- First Order Linear Recurrence --- Multiplication or Addition */
int mth$vffolrn_m_v8() ;
/*	MTH$VDFOLRN_M_V8 -- First Order Linear Recurrence --- Multiplication or Addition */
int mth$vdfolrn_m_v8();
/*	MTH$VGFOLRN_M_V8 -- First Order Linear Recurrence --- Multiplication or Addition */
int mth$vgfolrn_m_v8();
/*	MTH$VJFOLRP_A_V8 -- First Order Linear Recurrence --- Multiplication or Addition */
int mth$vjfolrp_a_v8();
/*	MTH$VFFOLRP_A_V8 -- First Order Linear Recurrence --- Multiplication or Addition */
int mth$vffolrp_a_v8();
/*	MTH$VDFOLRP_A_V8 -- First Order Linear Recurrence --- Multiplication or Addition */
int mth$vdfolrp_a_v8();
/*	MTH$VGFOLRP_A_V8 -- First Order Linear Recurrence --- Multiplication or Addition */
int mth$vgfolrp_a_v8();
/*	MTH$VJFOLRN_A_V8 -- First Order Linear Recurrence --- Multiplication or Addition */
int mth$vjfolrn_a_v8();
/*	MTH$VFFOLRN_A_V8 -- First Order Linear Recurrence --- Multiplication or Addition */
int mth$vffolrn_a_v8();
/*	MTH$VDFOLRN_A_V8 -- First Order Linear Recurrence --- Multiplication or Addition */
int mth$vdfolrn_a_v8();
/*	MTH$VGFOLRN_A_V8 -- First Order Linear Recurrence --- Multiplication or Addition */
int mth$vgfolrn_a_v8();
/*	MTH$HACOS	-- arc cosine of angle expressed in radians (H-floating value) */
int mth$hacos();
/*	MTH$HACOSD	-- arc cosine of angle expressed in degrees (H-floating value) */
int mth$hacosd();
/*	MTH$HASIN	-- arc sine in radians (H-floating value) */
int mth$hasin();
/*	MTH$HASIND	-- arc sine in degrees (H-floating value) */
int mth$hasind();
/*	MTH$HATAN	-- arc tangent in radians (H-floating value) */
int mth$hatan();
/*	MTH$HATAN2	-- arc tangent in radians (H-floating value) with two arguments */
int mth$hatan2();
/*	MTH$HATAND	-- arc tangent in degrees (H-floating value) */
int mth$hatand();
/*	MTH$HATANH	-- hyperbolic arc tangent (H-floating value) */
int mth$hatanh();
/*	MTH$HCOS	-- cosine of angle expressed in radians (H-floating value) */
int mth$hcos();
/*	MTH$HCOSD	-- cosine of angle expressed in degrees (H-floating value) */
int mth$hcosd();
/*	MTH$HCOSH	-- hyperbolic cosine (H-floating value) */
int mth$hcosh();
/*	MTH$HEXP	-- exponential (H-floating value) */
int mth$hexp();
/*	MTH$HLOG10	-- common logarithm (H-floating value) */
int mth$hlog10();
/*	MTH$HLOG	-- natural logarithm (H-floating value) */
int mth$hlog();
/*	MTH$HLOG2	-- base 2 logarithm (H-floating value) */
int mth$hlog2();
/*	MTH$HSIN	-- sine of angle expressed in radians (H-floating value) */
int mth$hsin();
/*	MTH$HSIND	-- sine of angle expressed in degrees (H-floating value) */
int mth$hsind();
/*	MTH$HSINH	-- hyperbolic sine (H-floating value) */
int mth$hsinh();
/*	MTH$HSQRT	-- square root (H-floating value) */
int mth$hsqrt();
/*	MTH$HTAN	-- tangent of angle expressed in radians (H-floating value) */
int mth$htan();
/*	MTH$HTAND	-- tangent of angle expressed in degrees (H-floating value) */
int mth$htand();
/*	MTH$HTANH	-- compute the hyperbolic tangent (H-floating value) */
int mth$htanh();
/*	MTH$HATAND2	-- arc tangent in degrees (H-floating value) with two arguments */
int mth$hatand2();

/*	MTH$AIMAG,MTH$DIMAG,MTH$GIMAG -- imaginary part of a complex number */
float mth$aimag();
double mth$dimag(), mth$gimag();
/*	MTH$ALOG,MTH$DLOG,MTH$GLOG -- natural logarithm */
float mth$alog();
double mth$dlog(), mth$glog();
/*	MTH$ALOG10,MTH$DLOG10,MTH$GLOG10 -- common logarithm */
float mth$alog10();
double mth$dlog10(), mth$glog10();
/*	MTH$ALOG2,MTH$DLOG2,MTH$GLOG2 -- base 2 logarithm */
float mth$alog2();
double mth$dlog2(), mth$glog2();
/*	MTH$RANDOM	-- random number generator, uniformly distributed */
float mth$random();
/*	MTH$REAL,MTH$DREAL,MTH$GREAL -- real part of a complex number */
float mth$real();
double mth$dreal(), mth$greal();
/*	MTH$SIN,MTH$DSIN,MTH$GSIN -- sine of angle expressed in radians */
float mth$sin();
double mth$dsin(), mth$gsin();
/*	MTH$SIND,MTH$DSIND,MTH$GSIND -- sine of angle expressed in degrees */
float mth$sind();
double mth$dsind(), mth$gsind();
/*	MTH$SINH,MTH$DSINH,MTH$GSINH -- hyperbolic sine */
float mth$sinh();
double mth$dsinh(), mth$gsinh();

/* sine and cosine of angle in radians */
/*	MTH$SINCOS,MTH$DSINCOS,MTH$GSINCOS,MTH$HSINCOS */
int mth$sincos(), mth$dsincos(), mth$gsincos(), mth$hsincos();
/* sine and cosine of angle in degrees */
/*	MTH$SINCOSD,MTH$DSINCOSD,MTH$GSINCOSD,MTH$HSINCOSD */
int mth$sincosd(), mth$dsincosd(), mth$gsincosd(), mth$hsincosd();

/*	MTH$SQRT,MTH$DSQRT,MTH$GSQRT -- square root */
float mth$sqrt();
double mth$dsqrt(), mth$gsqrt();
/*	MTH$TAN,MTH$DTAN,MTH$GTAN -- tangent of angle expressed in radians */
float mth$tan();
double mth$dtan(), mth$gtan();
/*	MTH$TAND,MTH$DTAND,MTH$GTAND -- tangent of angle expressed in degrees */
float mth$tand();
double mth$dtand(), mth$gtand();
/*	MTH$TANH,MTH$DTANH,MTH$GTANH -- compute the hyperbolic tangent */
float mth$tanh();
double mth$dtanh(), mth$gtanh();

/*	MTH$UMAX	-- compute unsigned maximum */
unsigned long mth$umax();
/*	MTH$UMIN	-- compute unsigned minimum */
unsigned long mth$umin();
/*	MTH$ABS,MTH$DABS,MTH$GABS,MTH$HABS -- floating absolute value */
float mth$abs();
double mth$dabs(), mth$gabs();
int mth$habs();			/*(no return value)*/
/*	MTH$IIABS,MTH$JIABS -- integer absolute value */
short mth$iiabs();
long mth$jiabs();
/*	MTH$IIAND	-- bitwise and of two word parameters */
unsigned short mth$iiand();
/*	MTH$JIAND	-- bitwise and of two longword parameters */
unsigned long mth$jiand();
/*	MTH$DBLE,MTH$GDBLE -- convert floating to double-precision (exact) */
double mth$dble(), mth$gdble();
/*	MTH$DIM,MTH$DDIM,MTH$GDIM,MTH$HDIM -- positive difference of two floating parameters */
float mth$dim();
double mth$ddim(), mth$gdim();
int mth$hdim();			/*(no return value)*/
/*	MTH$IIDIM,MTH$JIDIM -- positive difference of two integer parameters */
short mth$iidim();
long mth$jidim();
/*	MTH$IIEOR	-- bitwise exclusive or of two word parameters */
unsigned short mth$iieor();
/*	MTH$JIEOR	-- bitwise exclusive or of two longword parameters */
unsigned long mth$jieor();
/*	MTH$IIFIX	-- convert F-floating to word (truncated) */
short mth$iifix();
/*	MTH$JIFIX	-- convert F-floating to longword (truncated) */
long mth$jifix();

/*	MTH$FLOATI,MTH$DFLOTI,MTH$GFLOTI -- convert word to floating (exact) */
float mth$floati();
double mth$dfloti(), mth$gfloti();
/*	MTH$FLOATJ,MTH$DFLOTJ,MTH$GFLOTJ -- convert longword to G-floating (exact) */
float mth$floatj();
double mth$dflotj(), mth$gflotj();

/*	MTH$FLOOR,MTH$DFLOOR,MTH$GFLOOR,MTH$HFLOOR -- convert floating to greater floating integer */
float mth$floor();
double mth$dfloor(), mth$gfloor();
int mth$hfloor();		/*(no return value)*/
/*	MTH$AINT	-- convert F-floating to truncated F-floating */
float mth$aint();
/*	MTH$DINT	-- convert D-floating to truncated D-floating */
double mth$dint();
/*	MTH$IIDINT	-- convert D-floating to word (truncated) */
short mth$iidint();
/*	MTH$JIDINT	-- convert D-floating to longword (truncated) */
long mth$jidint();
/*	MTH$GINT	-- convert G-floating to G-floating (truncated) */
double mth$gint();
/*	MTH$IIGINT	-- convert G-floating to word (truncated) */
short mth$iigint();
/*	MTH$JIGINT	-- convert G-floating to longword (truncated) */
long mth$jigint();
/*	MTH$HINT	-- convert H-floating to H-floating (truncated) */
int mth$hint();
/*	MTH$IIHINT	-- convert H-floating to truncated word */
short mth$iihint();
/*	MTH$JIHINT	-- convert H-floating to truncated longword */
long mth$jihint();
/*	MTH$IINT	-- convert F-floating to word (truncated) */
short mth$iint();
/*	MTH$JINT	-- convert f-floating to longword (truncated) */
long mth$jint();
/*	MTH$IIOR	-- bitwise inclusive or of two word parameters */
unsigned short mth$iior();
/*	MTH$JIOR	-- bitwise inclusive or of two longword parameters */
unsigned long mth$jior();
/*	MTH$AIMAX0	-- F-floating maximum of N word parameters */
float mth$aimax0();
/*	MTH$AJMAX0	-- F-floating maximum of N longword parameters */
float mth$ajmax0();
/*	MTH$IMAX0	-- word maximum of N word parameters */
short mth$imax0();
/*	MTH$JMAX0	-- longword maximum of N longword parameters */
long mth$jmax0();
/*	MTH$AMAX1	-- F-floating maximum of N F-floating parameters */
float mth$amax1();
/*	MTH$DMAX1	-- D-floating maximum of N D-floating parameters */
double mth$dmax1();
/*	MTH$GMAX1	-- G-floating maximum of N G-floating parameters */
double mth$gmax1();
/*	MTH$HMAX1	-- H-floating maximum of N H-floating parameters */
int mth$hmax1();
/*	MTH$IMAX1	-- word maximum of N F-floating parameters */
short mth$imax1();
/*	MTH$JMAX1	-- longword maximum of N F-floating parameters */
long mth$jmax1();
/*	MTH$AIMIN0	-- F-floating minimum of N word parameters */
float mth$aimin0();
/*	MTH$AJMIN0	-- F-floating minimum of N longword parameters */
float mth$ajmin0();
/*	MTH$IMIN0	-- word minimum of N word parameters */
short mth$imin0();
/*	MTH$JMIN0	-- longword minimum of N longword parameters */
long mth$jmin0();
/*	MTH$AMIN1	-- F-floating minimum of N F-floating parameters */
float mth$amin1();
/*	MTH$DMIN1	-- D-floating minimum of N D-floating parameters */
double mth$dmin1();
/*	MTH$GMIN1	-- G-floating minimum of N G-floating parameters */
double mth$gmin1();
/*	MTH$HMIN1	-- H-floating minimum of N H-floating parameters */
int mth$hmin1();
/*	MTH$IMIN1	-- word minimum of N F-floating parameters */
short mth$imin1();
/*	MTH$JMIN1	-- longword minimum of N F-floating parameters */
long mth$jmin1();

/*	MTH$AMOD,MTH$DMOD,MTH$GMOD,MTH$HMOD -- remainder of two floating parameters */
float mth$amod();
double mth$dmod(), mth$gmod();
int mth$hmod();			/*(no return value)*/
/*	MTH$IMOD,MTH$JMOD -- remainder of two integer parameters */
short mth$imod();
long mth$jmod();

/*	MTH$ANINT,MTH$DNINT,MTH$GNINT,MTH$HNINT -- convert floating to nearest floating integer */
float mth$anint();
double mth$dnint(), mth$gnint();
int mth$hnint();		/*(no return value)*/
/*	MTH$ININT,MTH$JNINT -- convert F-floating to nearest integer */
short mth$inint();
long mth$jnint();
/*	MTH$IIDNNT,MTH$JIDNNT -- convert D-floating to nearest integer */
short mth$iidnnt();
long mth$jidnnt();
/*	MTH$IIGNNT,MTH$JIGNNT -- convert G-floating to nearest integer */
short mth$iignnt();
long mth$jignnt();
/*	MTH$IIHNNT,MTH$JIHNNT -- convert H-floating to nearest integer */
short mth$iihnnt();
long mth$jihnnt();
/*	MTH$INOT	-- bitwise complement of word parameter */
unsigned short mth$inot();
/*	MTH$JNOT	-- bitwise complement of longword parameter */
unsigned long mth$jnot();
/*	MTH$DPROD,MTH$GPROD -- double-precision product of two F-floating parameters */
double mth$dprod(), mth$gprod();
/*	MTH$SGN		-- F-floating sign function */
long mth$sgn();
/*	MTH$IISHFT	-- bitwise shift of word */
unsigned short mth$iishft();
/*	MTH$JISHFT	-- bitwise shift of longword */
unsigned long mth$jishft();
/*	MTH$SIGN	-- F-floating transfer of sign */
float mth$sign();
/*	MTH$DSIGN	-- D-floating transfer of sign */
double mth$dsign();
/*	MTH$GSIGN	-- G-floating transfer of sign */
double mth$gsign();
/*	MTH$HSIGN	-- H-floating transfer of sign */
int mth$hsign();
/*	MTH$IISIGN	-- word transfer of sign */
short mth$iisign();
/*	MTH$JISIGN	-- longword transfer of sign */
long mth$jisign();
/*	MTH$SNGL,MTH$SNGLG -- convert double-precision to F-floating (rounded) */
float mth$sngl(), mth$snglg();

# ifdef __cplusplus
}
# endif
#endif	/*_MTH$ROUTINES_H*/
