/* <ots$routines.h>
 *
 *	Compiler support run-time library routines.
 */
#ifndef _OTS$ROUTINES_H
#define _OTS$ROUTINES_H
# ifdef __cplusplus
extern "C" {
# endif

/*	OTS$CVT_T_D,OTS$CVT_T_F,OTS$CVT_T_G,OTS$CVT_T_H -- convert numeric text to floating value */
unsigned long ots$cvt_t_d(const void *,double *,...),
	      ots$cvt_t_f(const void *,float *,...),
	      ots$cvt_t_g(const void *,double *,...),
	      ots$cvt_t_h(const void *,void *,...);

/*	OTS$DIVC,OTS$DIVCD_R3,OTS$DIVCG_R3 -- Complex Division */
 /*- complex ots$divc(complex,complex); */
 /*- double complex ots$divcd_r3(), ots$divcg_r3(); */

/*	OTS$DIV_PK_LONG -- packed decimal division with long divisor */
/*	OTS$DIV_PK_SHORT-- packed decimal division with short divisor */
unsigned long ots$div_pk_long(const void *,const void *,short,void *,short,short,short),
	      ots$div_pk_short(const void *,const void *,short,void *,short,short);

/*	OTS$MOVE3	-- move data without fill */
/*	OTS$MOVE5	-- move data with fill */
void ots$move3(int,const void *,void *),
     ots$move5(int,const void *,int,int,void *);

/*	OTS$MULCD_R3,OTS$MULCG_R3 -- complex multiplication */
 /*- double complex ots$mulc_r3(); */

/*	OTS$CNVOUT,OTS$CNVOUT_G,OTS$CNVOUT_H -- convert {D|G|H}-floating number to character string */
unsigned long ots$cnvout(const double *,void *,unsigned),
	      ots$cnvout_g(const double *,void *,unsigned),
	      ots$cnvout_h(const void *,void *,unsigned);

/*	OTS$POWCC,OTS$POWCDCD_R3,OTS$POWCDCG_R3 -- raise a complex base to a complex floating-point exponent */
 /*- complex ots$powcc(complex,complex); */
 /*- double complex ots$powcdcd_r3(), ots$powcgcg_r3(); */
/*	OTS$POWCJ,OTS$POWCDJ_R3,OTS$POWCGJ_R3 -- raise a complex base to a signed longword integer exponent */
 /*- complex ots$powcj(complex,long); */
 /*- double complex ots$powcdj_r3(), ots$powcgj_r3(); */

/*	OTS$POWDD	-- raise a D_floating base to D_floating exponent */
/*	OTS$POWDJ	-- raise a D_floating base to a longword exponent */
/*	OTS$POWDR	-- raise a D_floating base to an F_floating exponent */
/*	OTS$POWGG	-- raise a G-floating base to a G-floating exponent */
/*	OTS$POWGJ	-- raise a G-floating base to a longword exponent */
double ots$powdd(double,double),
       ots$powdj(double,long),
       ots$powdr(double,float),
       ots$powgg(double,double),
       ots$powgj(double,long);

/*	OTS$POWHH_R3	-- raise an H-floating base to an H-floating exponent */
/*	OTS$POWHJ_R3	-- raise an H-floating base to a longword exponent */
 /*- long double ots$powhh_r3(), ots$powhj_r3() */

/*	OTS$POWII	-- raise a word base to a word exponent */
/*	OTS$POWJJ	-- raise a longword base to a longword exponent */
/*	OTS$POWLULU	-- raise an unsigned longword base to an unsigned longword exponent */
short ots$powii(short,short);
long ots$powjj(long,long);
unsigned long ots$powlulu(unsigned long,unsigned long);

/*	OTS$POWRD	-- raise an F-floating base to a D-floating exponent */
/*	OTS$POWRJ	-- raise an F-floating base to a longword exponent */
/*	OTS$POWRR	-- raise an F-floating base to an F-floating exponent */
double ots$powrd(float,double);
float ots$powrj(float,long), ots$powrr(float,float);

/* raise a floating-point base to an unsigned longword integer exponent */
/*	OTS$POWRLU,OTS$POWDLU,OTS$POWGLU,OTS$POWHLU_R3 */
float ots$powrlu(float,unsigned long);
double ots$powdlu(double,unsigned long), ots$powglu(double,unsigned long);
 /*- long double ots$powhlu_r3(); */

/*	OTS$SCOPY_DXDX	-- copy a source string passed by descriptor to a destination string */
/*	OTS$SCOPY_R_DX	-- copy a source string passed by reference to a destination string */
unsigned short ots$scopy_dxdx(const void *,void *),
	       ots$scopy_r_dx(unsigned short,const void *,void *);
/*	OTS$SFREE1_DD	-- strings, free one dynamic */
/*	OTS$SFREEN_DD	-- strings, free N dynamic */
/*	OTS$SGET1_DD	-- strings, get one dynamic */
void ots$sfree1_dd(void *),
     ots$sfreen_dd(unsigned,void *),
     ots$sget1_dd(unsigned short,void *);

/*	OTS$CVT_L_TB	-- convert an unsigned integer to binary text */
/*	OTS$CVT_L_TI	-- convert signed integer to decimal text */
/*	OTS$CVT_L_TL	-- convert integer to logical text */
/*	OTS$CVT_L_TO	-- convert unsigned integer to octal text */
/*	OTS$CVT_L_TU	-- convert unsigned integer to decimal text */
/*	OTS$CVT_L_TZ	-- convert integer to hexadecimal text */
unsigned long ots$cvt_l_tb(const void *,void *,...),
	      ots$cvt_l_ti(const void *,void *,...),
	      ots$cvt_l_tl(const long *,void *),
	      ots$cvt_l_to(const void *,void *,...),
	      ots$cvt_l_tu(const void *,void *,...),
	      ots$cvt_l_tz(const void *,void *,...);

/*	OTS$CVT_TB_L	-- convert binary text to unsigned integer */
/*	OTS$CVT_TI_L	-- convert signed integer text to integer */
/*	OTS$CVT_TL_L	-- convert logical text to integer */
/*	OTS$CVT_TO_L	-- convert octal text to signed integer */
/*	OTS$CVT_TU_L	-- convert unsigned decimal text to integer */
/*	OTS$CVT_TZ_L	-- convert hexadecimal text to unsigned integer */
unsigned long ots$cvt_tb_l(const void *,void *,...),
	      ots$cvt_ti_l(const void *,void *,...),
	      ots$cvt_tl_l(const void *,void *,...),
	      ots$cvt_to_l(const void *,void *,...),
	      ots$cvt_tu_l(const void *,void *,...),
	      ots$cvt_tz_l(const void *,void *,...);

# ifdef __cplusplus
}
# endif
#endif	/*_OTS$ROUTINES_H*/
