/*
 * smg$create_virtual_display.c
 *
 *	Create a virtual display
 *
 * Bugs:
 *
 *	I'm making the assumption that unsigned long is the
 *	same size as a pointer. This allows for a much more
 *	generic creation of the virtual display id.
 *
 * History
 *
 *	06/08/1998 - Kevin Handy
 *		Initial version
 */

#include "smg$routines.h"
#include "smgdef.h"
#include "smgmsg.h"
#include "smgstarlet.h"
#include "libdef.h"
#include "descrip.h"
#include <stdlib.h>

/*
 * Main function
 */
unsigned long smg$create_virtual_display(long *rows,
	long *columns, unsigned long* displayid,
	unsigned long *display_attributes,
	unsigned long *video_attributes,
	unsigned long *character_set)
{
	int add_border = 0;		/* Additional lines needed for border */
	struct virtual_display_struct *vd;

	/*
	 * Allocate memory for a structure to contain all the useful
	 * items that we need to keep track of
	 */
	vd = malloc(sizeof *vd);
	if (vd == NULL)
	{
		return LIB$_INSVIRMEM;
	}

	/*
	 * Copy in all the passed information
	 */
	vd->rows = *rows;
	vd->columns = *columns;
	if (display_attributes != NULL)
	{
		vd->display_attribute = *display_attributes;
	}
	else
	{
		vd->display_attribute = 0;
	}
	if (video_attributes != NULL)
	{
		vd->video_attribute = *video_attributes;
	}
	if (character_set != NULL)
	{
		vd->character_set = *character_set;
	}
	else
	{
		vd->character_set = 0;
	}

	/*
	 * Do we need to make an adjustment to the size for an additional
	 * border around everything?
	 */
	if ((vd->video_attribute & (SMG$M_BORDER | SMG$M_BLOCK_BORDER)) != 0)
	{
		add_border = 2;
	}

	/*
	 * Create a window/panel to use
	 */
	vd->window = newwin(vd->rows, vd->columns, 0, 0);

	/*
	 * return a good status
	 */
	return SMG$_NORMAL;
}

